@@ -19,6 +19,16 @@ class Plugin:  # pragma: no cover
         """
         raise NotImplementedError
 
+    def get_tools(self) -> typing.List[typing.Tuple[str, str, str, typing.Callable]]:
+        """
+        Get the toolbar items required by the plugin.
+
+        Returns a list of strings and callables, where the strings are the label, the tool tip
+        and a path to an icon, the callable a callback that will be executed when the menu
+        item is selected.
+        """
+        raise NotImplementedError
+
     def connect(self, plugin_interface: PluginInterface):
         """
         Connects the plugin host and the plugin.
